from warnings import catch_warnings
import graphene
from graphene.types.structures import List
from graphene_django import DjangoObjectType
from blog.models import Autor

from blog.models import Autor, Articulo, Categoria

class AutorType(DjangoObjectType):
    class Meta:
        model = Autor
        fields = ("id", "nombre", "apellidos", "usuario")

class ArticuloType(DjangoObjectType):
    class Meta:
        model = Articulo
        fields = ("id", "titulo", "contenido","autor", "categoria")

class CategoriaType(DjangoObjectType):
    class Meta:
        model = Categoria
        fields = ("id", "nombre")

#--------------------------------------------------------------------------------------------------------------------------------------        

class Query(graphene.ObjectType):
    todos_autores = graphene.List(AutorType)
    articulos_por_autor = graphene.List(ArticuloType, id=graphene.Int(required=True))

    def resolve_todos_autores(root, info):
        return Autor.objects.all()

    def resolve_articulos_por_autor(root, info, id):
        return Articulo.objects.select_related('autor').select_related("categoria").filter(autor=id)

#--------------------------------------------------------------------------------------------------------------------------------------        

class AutorInput(graphene.InputObjectType):
    nombre = graphene.String()
    apellidos = graphene.String()
    usuario = graphene.String()

class CrearAutor(graphene.Mutation):
    class Arguments:
        usuario = graphene.String()
        nombre = graphene.String()
        apellidos = graphene.String()

    autor = graphene.Field(AutorType)
    success = graphene.Boolean(default_value=True)
    errors = graphene.String()

#    @staticmethod
#    def mutate(root, info, input):
#        try:
#            autor_instance = Autor(
#            nombre=input.nombre,
#            apellidos=input.apellidos,
#            usuario=input.usuario
#            )
#            autor_instance.save()
#            success = True
#            return CrearAutor(autor=autor_instance, success=success)
#        except ValueError as e:
#            success = False
#            return CrearAutor(autor=autor_instance, success=success)

    @classmethod
    def mutate(cls, root, info, usuario, nombre, apellidos):
        try:
            autor_instance = Autor(
                nombre = nombre,
                apellidos = apellidos,
                usuario = usuario
            )

            autor_instance.save()
            return cls(success = True, autor = autor_instance)
        except Exception as e:
            return cls(success = False, errors=str(e))

        



class Mutation(graphene.ObjectType):
    crear_autor = CrearAutor.Field()
        
schema = graphene.Schema(query=Query, mutation=Mutation)